@@ -13,7 +13,7 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
-* $Id: test_utils.c 1914 2008-01-30 09:38:37Z dermoth $
+* $Id: test_utils.c 2042 2008-08-21 15:18:58Z tonvoon $
 * 
 *****************************************************************************/
 
@@ -30,7 +30,7 @@ main (int argc, char **argv)
 	thresholds *thresholds = NULL;
 	int	rc;
 
-	plan_tests(82);
+	plan_tests(81);
 
 	range = parse_range_string("6");
 	ok( range != NULL, "'6' is valid range");
@@ -174,8 +174,5 @@ main (int argc, char **argv)
 	ok( strcmp(test, "everything") == 0, "everything okay");
 	free(test);
 
-	test = basename("/here/is/a/path");
-	ok( strcmp(test, "path") == 0, "basename okay");
-
 	return exit_status();
 }
