@@ -6,7 +6,7 @@
 * Copyright (c) 2005-2008 Nagios Plugins Development Team
 * Original Author : Andreas Ericsson <ae@op5.se>
 * 
-* Last Modified: $Date: 2008-05-07 11:02:42 +0100 (Wed, 07 May 2008) $
+* Last Modified: $Date: 2008-08-08 03:08:08 +0100 (Fri, 08 Aug 2008) $
 * 
 * Description:
 * 
@@ -35,14 +35,14 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
-* $Id: check_icmp.c 1991 2008-05-07 10:02:42Z dermoth $
+* $Id: check_icmp.c 2029 2008-08-08 02:08:08Z dermoth $
 * 
 *****************************************************************************/
 
 /* progname may change */
 /* char *progname = "check_icmp"; */
 char *progname;
-const char *revision = "$Revision: 1991 $";
+const char *revision = "$Revision: 2029 $";
 const char *copyright = "2005-2008";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -203,7 +203,9 @@ extern char **environ;
 static struct rta_host **table, *cursor, *list;
 static threshold crit = {80, 500000}, warn = {40, 200000};
 static int mode, protocols, sockets, debug = 0, timeout = 10;
-static unsigned short icmp_pkt_size, icmp_data_size = DEFAULT_PING_DATA_SIZE;
+static unsigned short icmp_data_size = DEFAULT_PING_DATA_SIZE;
+static unsigned short icmp_pkt_size = DEFAULT_PING_DATA_SIZE + ICMP_MINLEN;
+
 static unsigned int icmp_sent = 0, icmp_recv = 0, icmp_lost = 0;
 #define icmp_pkts_en_route (icmp_sent - (icmp_recv + icmp_lost))
 static unsigned short targets_down = 0, targets = 0, packets = 0;
@@ -453,12 +455,22 @@ main(int argc, char **argv)
 	/* parse the arguments */
 	for(i = 1; i < argc; i++) {
 		while((arg = getopt(argc, argv, "vhVw:c:n:p:t:H:s:i:b:I:l:m:")) != EOF) {
+			long size;
 			switch(arg) {
 			case 'v':
 				debug++;
 				break;
 			case 'b':
-				/* silently ignored for now */
+				size = strtol(optarg,NULL,0);
+				if (size >= (sizeof(struct icmp) + sizeof(struct icmp_ping_data)) &&
+				    size < MAX_PING_DATA) {
+					icmp_data_size = size;
+					icmp_pkt_size = size + ICMP_MINLEN;
+				} else
+					usage_va("ICMP data length must be between: %d and %d",
+					         sizeof(struct icmp) + sizeof(struct icmp_ping_data),
+					         MAX_PING_DATA - 1);
+
 				break;
 			case 'i':
 				pkt_interval = get_timevar(optarg);
@@ -587,13 +599,6 @@ main(int argc, char **argv)
 		}
 	}
 
-	icmp_pkt_size = icmp_data_size + ICMP_MINLEN;
-	if(debug > 2) printf("icmp_pkt_size = %u\n", icmp_pkt_size);
-	if(icmp_pkt_size < sizeof(struct icmp) + sizeof(struct icmp_ping_data)) {
-		icmp_pkt_size = sizeof(struct icmp) + sizeof(struct icmp_ping_data);
-	}
-	if(debug > 2) printf("icmp_pkt_size = %u\n", icmp_pkt_size);
-
 	if(debug) {
 		printf("crit = {%u, %u%%}, warn = {%u, %u%%}\n",
 			   crit.rta, crit.pl, warn.rta, warn.pl);
@@ -1291,12 +1296,13 @@ print_help(void)
   printf ("\n");
   printf (" %s\n", "-l");
   printf ("    %s", _("TTL on outgoing packets (currently "));
-  printf ("%u)", ttl);
+  printf ("%u)\n", ttl);
   printf (" %s\n", "-t");
   printf ("    %s",_("timeout value (seconds, currently  "));
   printf ("%u)\n", timeout);
   printf (" %s\n", "-b");
-  printf ("    %s\n", _("icmp packet size (currenly ignored)"));
+  printf ("    %s\n", _("Number of icmp data bytes to send")); 
+  printf ("    %s %u + %d)\n", _("Packet size will be data bytes + icmp header (currently"),icmp_data_size, ICMP_MINLEN);
   printf (" %s\n", "-v");
   printf ("    %s\n", _("verbose"));
 
