@@ -5,7 +5,7 @@
 * License: GPL
 * Copyright (c) 2002-2008 Nagios Plugins Development Team
 * 
-* Last Modified: $Date: 2008-05-07 11:02:42 +0100 (Wed, 07 May 2008) $
+* Last Modified: $Date: 2008-06-09 20:47:36 +0100 (Mon, 09 Jun 2008) $
 * 
 * Description:
 * 
@@ -25,7 +25,7 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
-* $Id: check_dig.c 1991 2008-05-07 10:02:42Z dermoth $
+* $Id: check_dig.c 2011 2008-06-09 19:47:36Z psychotrahe $
 * 
 *****************************************************************************/
 
@@ -36,7 +36,7 @@
  *  because on some architectures those strings are in non-writable memory */
 
 const char *progname = "check_dig";
-const char *revision = "$Revision: 1991 $";
+const char *revision = "$Revision: 2011 $";
 const char *copyright = "2002-2008";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -143,8 +143,10 @@ main (int argc, char **argv)
     }
   }
 
-  if (result == STATE_UNKNOWN)
+  if (result == STATE_UNKNOWN) {
     msg = (char *)_("No ANSWER SECTION found");
+    result = STATE_CRITICAL;
+  }
 
   /* If we get anything on STDERR, at least set warning */
   if(chld_err.buflen > 0) {
@@ -295,7 +297,10 @@ process_arguments (int argc, char **argv)
 int
 validate_arguments (void)
 {
-  return OK;
+  if (query_address != NULL)
+    return OK;
+  else
+    return ERROR;
 }
 
 
@@ -357,7 +362,7 @@ void
 print_usage (void)
 {
   printf (_("Usage:"));
-  printf ("%s -H <host> -l <query_address> [-p <server port>]\n", progname);
+  printf ("%s -l <query_address> [-H <host>] [-p <server port>]\n", progname);
   printf (" [-T <query type>] [-w <warning interval>] [-c <critical interval>]\n");
   printf (" [-t <timeout>] [-a <expected answer address>] [-v]\n");
 }
