@@ -5,7 +5,7 @@
 * License: GPL
 * Copyright (c) 2000-2007 Nagios Plugins Development Team
 * 
-* Last Modified: $Date: 2008-05-07 11:02:42 +0100 (Wed, 07 May 2008) $
+* Last Modified: $Date: 2008-08-16 05:47:22 +0100 (Sat, 16 Aug 2008) $
 * 
 * Description:
 * 
@@ -28,12 +28,12 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
-* $Id: check_fping.c 1991 2008-05-07 10:02:42Z dermoth $
+* $Id: check_fping.c 2033 2008-08-16 04:47:22Z dermoth $
 * 
 *****************************************************************************/
 
 const char *progname = "check_fping";
-const char *revision = "$Revision: 1991 $";
+const char *revision = "$Revision: 2033 $";
 const char *copyright = "2000-2007";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -391,9 +391,9 @@ print_help (void)
   printf (" %s\n", "-c, --critical=THRESHOLD");
   printf ("    %s\n", _("critical threshold pair"));
   printf (" %s\n", "-b, --bytes=INTEGER");
-  printf ("    %s\n", _("size of ICMP packet (default: %d)"),PACKET_SIZE);
+  printf ("    %s (default: %d)\n", _("size of ICMP packet"),PACKET_SIZE);
   printf (" %s\n", "-n, --number=INTEGER");
-  printf ("    %s\n", _("number of ICMP packets to send (default: %d)"),PACKET_COUNT);
+  printf ("    %s (default: %d)\n", _("number of ICMP packets to send"),PACKET_COUNT);
   printf (_(UT_VERBOSE));
   printf ("\n");
   printf (" %s\n", _("THRESHOLD is <rta>,<pl>%% where <rta> is the round trip average travel time (ms)"));
