@@ -6,7 +6,7 @@
 * Copyright (c) 2006-2007 Nagios Plugins Development Team
 * Original code from check_mysql, copyright 1999 Didi Rieder
 * 
-* Last Modified: $Date: 2008-05-07 11:02:42 +0100 (Wed, 07 May 2008) $
+* Last Modified: $Date: 2008-08-16 05:47:32 +0100 (Sat, 16 Aug 2008) $
 * 
 * Description:
 * 
@@ -28,12 +28,12 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
-* $Id: check_mysql_query.c 1991 2008-05-07 10:02:42Z dermoth $
+* $Id: check_mysql_query.c 2034 2008-08-16 04:47:32Z dermoth $
 * 
 *****************************************************************************/
 
 const char *progname = "check_mysql_query";
-const char *revision = "$Revision: 1991 $";
+const char *revision = "$Revision: 2034 $";
 const char *copyright = "1999-2007";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -271,7 +271,7 @@ validate_arguments (void)
 		db_host = strdup("");
 
 	if (db_pass == NULL)
-		db_pass == strdup("");
+		db_pass = strdup("");
 
 	if (db == NULL)
 		db = strdup("");
