@@ -6,7 +6,7 @@
 * Copyright (c) 2006 Sean Finney <seanius@seanius.net>
 * Copyright (c) 2006-2008 Nagios Plugins Development Team
 * 
-* Last Modified: $Date: 2008-05-07 11:02:42 +0100 (Wed, 07 May 2008) $
+* Last Modified: $Date: 2008-09-02 13:28:04 +0100 (Tue, 02 Sep 2008) $
 * 
 * Description:
 * 
@@ -34,12 +34,12 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
-* $Id: check_ntp_peer.c 1991 2008-05-07 10:02:42Z dermoth $
+* $Id: check_ntp_peer.c 2054 2008-09-02 12:28:04Z dermoth $
 * 
 *****************************************************************************/
 
 const char *progname = "check_ntp_peer";
-const char *revision = "$Revision: 1991 $";
+const char *revision = "$Revision: 2054 $";
 const char *copyright = "2006-2008";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -48,6 +48,7 @@ const char *email = "nagiosplug-devel@lists.sourceforge.net";
 #include "utils.h"
 
 static char *server_address=NULL;
+static int port=123;
 static int verbose=0;
 static int quiet=0;
 static short do_offset=0;
@@ -175,23 +176,56 @@ void print_ntp_control_message(const ntp_control_message *p){
 	}
 }
 
+/*
+ * Extract the value from NTP key/value pairs, or return NULL.
+ * The value returned can be free()ed.
+ */
 char *extract_value(const char *varlist, const char *name){
-	char *tmpvarlist=NULL, *tmpkey=NULL, *value=NULL;
-	int last=0;
+	char *tmp=NULL, *value=NULL;
+	int i;
 
-	/* The following code require a non-empty varlist */
-	if(strlen(varlist) == 0)
-		return NULL;
+	while (1) {
+		/* Strip any leading space */
+		for (varlist; isspace(varlist[0]); varlist++);
 
-	tmpvarlist = strdup(varlist);
-	tmpkey = strtok(tmpvarlist, "=");
+		if (strncmp(name, varlist, strlen(name)) == 0) {
+			varlist += strlen(name);
+			/* strip trailing spaces */
+			for (varlist; isspace(varlist[0]); varlist++);
 
-	do {
-		if(strstr(tmpkey, name) != NULL) {
-		value = strtok(NULL, ",");
-			last = 1;
+			if (varlist[0] == '=') {
+				/* We matched the key, go past the = sign */
+				varlist++;
+				/* strip leading spaces */
+				for (varlist; isspace(varlist[0]); varlist++);
+
+				if (tmp = index(varlist, ',')) {
+					/* Value is delimited by a comma */
+					if (tmp-varlist == 0) continue;
+					value = (char *)malloc(tmp-varlist+1);
+					strncpy(value, varlist, tmp-varlist);
+					value[tmp-varlist] = '\0';
+				} else {
+					/* Value is delimited by a \0 */
+					if (strlen(varlist) == 0) continue;
+					value = (char *)malloc(strlen(varlist) + 1);
+					strncpy(value, varlist, strlen(varlist));
+					value[strlen(varlist)] = '\0';
+				}
+				break;
+			}
 		}
-	} while (last == 0 && (tmpkey = strtok(NULL, "=")));
+		if (tmp = index(varlist, ',')) {
+			/* More keys, keep going... */
+			varlist = tmp + 1;
+		} else {
+			/* We're done */
+			break;
+		}
+	}
+
+	/* Clean-up trailing spaces/newlines */
+	if (value) for (i=strlen(value)-1; isspace(value[i]); i--) value[i] = '\0';
 
 	return value;
 }
@@ -250,7 +284,7 @@ int ntp_request(const char *host, double *offset, int *offset_result, double *ji
 	 * 4) Extract the offset, jitter and stratum value from the data[]
 	 *    (it's ASCII)
 	 */
-	my_udp_connect(server_address, 123, &conn);
+	my_udp_connect(server_address, port, &conn);
 
 	/* keep sending requests until the server stops setting the
 	 * REM_MORE bit, though usually this is only 1 packet. */
@@ -265,6 +299,9 @@ int ntp_request(const char *host, double *offset, int *offset_result, double *ji
 		if(read(conn, &req, SIZEOF_NTPCM(req)) == -1)
 			die(STATE_CRITICAL, "NTP CRITICAL: No response from NTP server\n");
 		DBG(print_ntp_control_message(&req));
+		/* discard obviously invalid packets */
+		if (ntohs(req.count) > MAX_CM_SIZE)
+			die(STATE_CRITICAL, "NTP CRITICAL: Invalid packet received from NTP server\n");
 		if (LI(req.flags) == LI_ALARM) li_alarm = 1;
 		/* Each peer identifier is 4 bytes in the data section, which
 	 	 * we represent as a ntp_assoc_status_pair datatype.
@@ -436,6 +473,7 @@ int process_arguments(int argc, char **argv){
 		{"jcrit", required_argument, 0, 'k'},
 		{"timeout", required_argument, 0, 't'},
 		{"hostname", required_argument, 0, 'H'},
+		{"port", required_argument, 0, 'p'},
 		{0, 0, 0, 0}
 	};
 
@@ -444,7 +482,7 @@ int process_arguments(int argc, char **argv){
 		usage ("\n");
 
 	while (1) {
-		c = getopt_long (argc, argv, "Vhv46qw:c:W:C:j:k:t:H:", longopts, &option);
+		c = getopt_long (argc, argv, "Vhv46qw:c:W:C:j:k:t:H:p:", longopts, &option);
 		if (c == -1 || c == EOF || c == 1)
 			break;
 
@@ -492,6 +530,9 @@ int process_arguments(int argc, char **argv){
 				usage2(_("Invalid hostname/address"), optarg);
 			server_address = strdup(optarg);
 			break;
+		case 'p':
+			port=atoi(optarg);
+			break;
 		case 't':
 			socket_timeout=atoi(optarg);
 			break;
