@@ -5,7 +5,7 @@
 * License: GPL
 * Copyright (c) 1999-2007 Nagios Plugins Development Team
 * 
-* Last Modified: $Date: 2008-05-07 11:02:42 +0100 (Wed, 07 May 2008) $
+* Last Modified: $Date: 2008-07-09 22:53:12 +0100 (Wed, 09 Jul 2008) $
 * 
 * Description:
 * 
@@ -27,12 +27,12 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
-* $Id: check_snmp.c 1991 2008-05-07 10:02:42Z dermoth $
+* $Id: check_snmp.c 2021 2008-07-09 21:53:12Z psychotrahe $
 * 
 *****************************************************************************/
 
 const char *progname = "check_snmp";
-const char *revision = "$Revision: 1991 $";
+const char *revision = "$Revision: 2021 $";
 const char *copyright = "1999-2007";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -228,14 +228,14 @@ main (int argc, char **argv)
 
 	strncat(perfstr, "| ", sizeof(perfstr)-strlen(perfstr)-1);
 	while (ptr) {
-		char *foo;
+		char *foo, *ptr2;
 		unsigned int copylen;
 
 		foo = strstr (ptr, delimiter);
 		copylen = foo-ptr;
 		if (copylen > sizeof(perfstr)-strlen(perfstr)-1)
 			copylen = sizeof(perfstr)-strlen(perfstr)-1;
-		strncat(perfstr, ptr, copylen);
+		ptr2 = ptr;
 		ptr = foo; 
 
 		if (ptr == NULL)
@@ -368,11 +368,15 @@ main (int argc, char **argv)
 
 		i++;
 
-		strncat(perfstr, "=", sizeof(perfstr)-strlen(perfstr)-1);
-		strncat(perfstr, show, sizeof(perfstr)-strlen(perfstr)-1);
-		if (type)
-			strncat(perfstr, type, sizeof(perfstr)-strlen(perfstr)-1);
-		strncat(perfstr, " ", sizeof(perfstr)-strlen(perfstr)-1);
+		if (is_numeric(show)) {
+			strncat(perfstr, ptr2, copylen);
+			strncat(perfstr, "=", sizeof(perfstr)-strlen(perfstr)-1);
+			strncat(perfstr, show, sizeof(perfstr)-strlen(perfstr)-1);
+
+			if (type)
+				strncat(perfstr, type, sizeof(perfstr)-strlen(perfstr)-1);
+			strncat(perfstr, " ", sizeof(perfstr)-strlen(perfstr)-1);
+		}
 
 	}	/* end while (ptr) */
 
